@@ -1680,4 +1680,4 @@ def ClassifyBehavior(data,video, bodyparts_list, dimensions = 2,distance=28,**kw
       return cluster_labels, data_emb, model, data_HDim, knn, knc, cpd
 
     else:
-      return cluster_labels, data_emb, model, data_HDim
\ No newline at end of file
+      return cluster_labels, X_transformed, model, d[startIndex:endIndex]
\ No newline at end of file
